@@ -1,9 +1,10 @@
 package List::Objects::WithUtils::Hash::Inflated;
 {
-  $List::Objects::WithUtils::Hash::Inflated::VERSION = '2.002002';
+  $List::Objects::WithUtils::Hash::Inflated::VERSION = '2.002003';
 }
 use strictures 1;
-require Carp;
+use Carp ();
+use Scalar::Util ();
 
 sub new {
   bless +{ @_[1 .. $#_] }, $_[0]
@@ -30,8 +31,10 @@ sub can {
 }
 
 sub AUTOLOAD {
-  my $self = shift || return;
+  my $self = shift;
   ( my $method = $AUTOLOAD ) =~ s/.*:://;
+  Scalar::Util::blessed($self)
+    or Carp::confess "Not a class method: '$method'";
   
   Carp::confess "Can't locate object method '$method'"
     unless exists $self->{$method};
